==> nextcloud-20.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/it.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Cruscotto",
    "Dashboard app" : "Cruscotto",
    "Show something" : "Mostra qualcosa",
    "Customize" : "Personalizza",
    "Edit widgets" : "Modifica widget",
    "Get more widgets from the app store" : "Ottieni altri widget dal negozio di applicazioni",
    "Change background image" : "Cambia l'immagine di sfondo",
    "Weather service" : "Servizio meteo",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Per la tua riservatezza, i dati meteorologici sono richiesti dal tuo server Nextcloud per tuo conto, per cui il servizio meteo non riceve informazioni personali.",
    "Weather data from Met.no" : "Dati meteo da Met.no",
    "geocoding with Nominatim" : "geocodifica conh Nominatim",
    "elevation data from OpenTopoData" : "dati di elevazione da OpenTopoData",
    "Weather" : "Meteo",
    "Status" : "Stato",
    "Good evening, {name}" : "Buona sera, {name}",
    "Good evening" : "Buona sera",
    "Good afternoon, {name}" : "Buon pomeriggio, {name}",
    "Good afternoon" : "Buon pomeriggio",
    "Good morning, {name}" : "Buongiorno, {name}",
    "Good morning" : "Buongiorno",
    "Good night, {name}" : "Buona notte, {name}",
    "Good night" : "Buona notte",
    "Pick from files" : "Scegli da file",
    "Default images" : "Immagini predefinite",
    "Plain background" : "Sfondo semplice",
    "Insert from {productName}" : "Inserisci da {productName}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/it.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Cruscotto",
    "Dashboard app" : "Cruscotto",
    "Show something" : "Mostra qualcosa",
    "Customize" : "Personalizza",
    "Edit widgets" : "Modifica widget",
    "Get more widgets from the app store" : "Ottieni altri widget dal negozio di applicazioni",
    "Change background image" : "Cambia l'immagine di sfondo",
    "Weather service" : "Servizio meteo",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Per la tua riservatezza, i dati meteorologici sono richiesti dal tuo server Nextcloud per tuo conto, per cui il servizio meteo non riceve informazioni personali.",
    "Weather data from Met.no" : "Dati meteo da Met.no",
    "geocoding with Nominatim" : "geocodifica conh Nominatim",
    "elevation data from OpenTopoData" : "dati di elevazione da OpenTopoData",
    "Weather" : "Meteo",
    "Status" : "Stato",
    "Good morning" : "Buongiorno",
    "Good morning, {name}" : "Buongiorno, {name}",
    "Good afternoon" : "Buon pomeriggio",
    "Good afternoon, {name}" : "Buon pomeriggio, {name}",
    "Good evening" : "Buona sera",
    "Good evening, {name}" : "Buona sera, {name}",
    "Hello" : "Ciao",
    "Hello, {name}" : "Ciao {name}",
    "Pick from Files" : "Scegli da File",
    "Default images" : "Immagini predefinite",
    "Plain background" : "Sfondo semplice",
    "Insert from {productName}" : "Inserisci da {productName}",
    "Good night, {name}" : "Buona notte, {name}",
    "Good night" : "Buona notte",
    "Pick from files" : "Scegli da file"
},
"nplurals=2; plural=(n != 1);");
